==> jc-1.4.0.tar.gz: soot/dava/internal/javaRep/DNegExpr.h <==
// public class soot.dava.internal.javaRep.DNegExpr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e7676cf69e8c1a31 soot_dava_internal_javaRep_DNegExpr
// @dep_class f5a35044f0376f2e soot_jimple_internal_AbstractNegExpr
// @dep_class 2880d6831146619b soot_jimple_internal_AbstractUnopExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractNegExpr

#include "soot/jimple/internal/AbstractNegExpr.h"

#ifndef _JC_soot_dava_internal_javaRep_DNegExpr_H_
#define _JC_soot_dava_internal_javaRep_DNegExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_dava_internal_javaRep_DNegExpr$sub_refs	_jc_soot_dava_internal_javaRep_DNegExpr$sub_refs;
typedef struct _jc_soot_dava_internal_javaRep_DNegExpr$sub_nonrefs	_jc_soot_dava_internal_javaRep_DNegExpr$sub_nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DNegExpr$refs	_jc_soot_dava_internal_javaRep_DNegExpr$refs;
typedef struct _jc_soot_dava_internal_javaRep_DNegExpr$nonrefs	_jc_soot_dava_internal_javaRep_DNegExpr$nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DNegExpr$object	_jc_soot_dava_internal_javaRep_DNegExpr$object;

typedef const struct _jc_soot_dava_internal_javaRep_DNegExpr$vmethods	_jc_soot_dava_internal_javaRep_DNegExpr$vmethods;
typedef const struct _jc_soot_dava_internal_javaRep_DNegExpr$vtable	_jc_soot_dava_internal_javaRep_DNegExpr$vtable;
typedef const struct _jc_soot_dava_internal_javaRep_DNegExpr$vtype	_jc_soot_dava_internal_javaRep_DNegExpr$vtype;

// Constructors
extern void _jc_soot_dava_internal_javaRep_DNegExpr$method$_init$b01f06481db4410b(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNegExpr$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_dava_internal_javaRep_DNegExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNegExpr$object *);
extern struct _jc_java_lang_String$object *_jc_soot_dava_internal_javaRep_DNegExpr$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNegExpr$object *);
extern void _jc_soot_dava_internal_javaRep_DNegExpr$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNegExpr$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_javaRep_DNegExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_dava_internal_javaRep_DNegExpr$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_dava_internal_javaRep_DNegExpr$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_dava_internal_javaRep_DNegExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNegExpr$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNegExpr$object *);
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNegExpr$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_dava_internal_javaRep_DNegExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractUnopExpr$vmethods	soot_jimple_internal_AbstractUnopExpr;
	_jc_soot_jimple_internal_AbstractNegExpr$vmethods	soot_jimple_internal_AbstractNegExpr;
	_jc_soot_dava_internal_javaRep_DNegExpr$vmethods	soot_dava_internal_javaRep_DNegExpr;
};

// Vtype
struct _jc_soot_dava_internal_javaRep_DNegExpr$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_javaRep_DNegExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DNegExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DNegExpr$refs {
    _jc_soot_dava_internal_javaRep_DNegExpr$sub_refs	soot_dava_internal_javaRep_DNegExpr;
    _jc_soot_jimple_internal_AbstractNegExpr$sub_refs	soot_jimple_internal_AbstractNegExpr;
    _jc_soot_jimple_internal_AbstractUnopExpr$sub_refs	soot_jimple_internal_AbstractUnopExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DNegExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DNegExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractUnopExpr$sub_nonrefs	soot_jimple_internal_AbstractUnopExpr;
    _jc_soot_jimple_internal_AbstractNegExpr$sub_nonrefs	soot_jimple_internal_AbstractNegExpr;
    _jc_soot_dava_internal_javaRep_DNegExpr$sub_nonrefs	soot_dava_internal_javaRep_DNegExpr;
};

// Object instance structure
struct _jc_soot_dava_internal_javaRep_DNegExpr$object {
	_jc_soot_dava_internal_javaRep_DNegExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_javaRep_DNegExpr$vtype	*vtype;
	_jc_soot_dava_internal_javaRep_DNegExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_javaRep_DNegExpr$vtype _jc_soot_dava_internal_javaRep_DNegExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_javaRep_DNegExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_javaRep_DNegExpr$class_object;

#endif	/* _JC_soot_dava_internal_javaRep_DNegExpr_H_ */

==> jc-1.4.6.tar.gz: soot/dava/internal/javaRep/DNegExpr.h <==
// public class soot.dava.internal.javaRep.DNegExpr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e7676cf69e8c1a31 soot_dava_internal_javaRep_DNegExpr
// @dep_class f5a35044f0376f2e soot_jimple_internal_AbstractNegExpr
// @dep_class 2880d6831146619b soot_jimple_internal_AbstractUnopExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractNegExpr

#include "soot/jimple/internal/AbstractNegExpr.h"

#ifndef _JC_soot_dava_internal_javaRep_DNegExpr_H_
#define _JC_soot_dava_internal_javaRep_DNegExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_dava_internal_javaRep_DNegExpr$sub_refs	_jc_soot_dava_internal_javaRep_DNegExpr$sub_refs;
typedef struct _jc_soot_dava_internal_javaRep_DNegExpr$sub_nonrefs	_jc_soot_dava_internal_javaRep_DNegExpr$sub_nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DNegExpr$refs	_jc_soot_dava_internal_javaRep_DNegExpr$refs;
typedef struct _jc_soot_dava_internal_javaRep_DNegExpr$nonrefs	_jc_soot_dava_internal_javaRep_DNegExpr$nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DNegExpr$object	_jc_soot_dava_internal_javaRep_DNegExpr$object;

typedef const struct _jc_soot_dava_internal_javaRep_DNegExpr$vmethods	_jc_soot_dava_internal_javaRep_DNegExpr$vmethods;
typedef const struct _jc_soot_dava_internal_javaRep_DNegExpr$vtable	_jc_soot_dava_internal_javaRep_DNegExpr$vtable;
typedef const struct _jc_soot_dava_internal_javaRep_DNegExpr$vtype	_jc_soot_dava_internal_javaRep_DNegExpr$vtype;

// Constructors
extern void _jc_soot_dava_internal_javaRep_DNegExpr$method$_init$b01f06481db4410b(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNegExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_dava_internal_javaRep_DNegExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNegExpr$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_dava_internal_javaRep_DNegExpr$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNegExpr$object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_internal_javaRep_DNegExpr$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNegExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_javaRep_DNegExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_dava_internal_javaRep_DNegExpr$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_dava_internal_javaRep_DNegExpr$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_dava_internal_javaRep_DNegExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNegExpr$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNegExpr$object *) _JC_JCNI_ATTR;
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNegExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_dava_internal_javaRep_DNegExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractUnopExpr$vmethods	soot_jimple_internal_AbstractUnopExpr;
	_jc_soot_jimple_internal_AbstractNegExpr$vmethods	soot_jimple_internal_AbstractNegExpr;
	_jc_soot_dava_internal_javaRep_DNegExpr$vmethods	soot_dava_internal_javaRep_DNegExpr;
};

// Vtype
struct _jc_soot_dava_internal_javaRep_DNegExpr$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_javaRep_DNegExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DNegExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DNegExpr$refs {
    _jc_soot_dava_internal_javaRep_DNegExpr$sub_refs	soot_dava_internal_javaRep_DNegExpr;
    _jc_soot_jimple_internal_AbstractNegExpr$sub_refs	soot_jimple_internal_AbstractNegExpr;
    _jc_soot_jimple_internal_AbstractUnopExpr$sub_refs	soot_jimple_internal_AbstractUnopExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DNegExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DNegExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractUnopExpr$sub_nonrefs	soot_jimple_internal_AbstractUnopExpr;
    _jc_soot_jimple_internal_AbstractNegExpr$sub_nonrefs	soot_jimple_internal_AbstractNegExpr;
    _jc_soot_dava_internal_javaRep_DNegExpr$sub_nonrefs	soot_dava_internal_javaRep_DNegExpr;
};

// Object instance structure
struct _jc_soot_dava_internal_javaRep_DNegExpr$object {
	_jc_soot_dava_internal_javaRep_DNegExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_javaRep_DNegExpr$vtype	*vtype;
	_jc_soot_dava_internal_javaRep_DNegExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_javaRep_DNegExpr$vtype _jc_soot_dava_internal_javaRep_DNegExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_javaRep_DNegExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_javaRep_DNegExpr$class_object;

#endif	/* _JC_soot_dava_internal_javaRep_DNegExpr_H_ */
